@@ -22,19 +22,25 @@
 
 int main(int argc, char **argv)
 {
+    int q = 0;
     char* with_what = " ";
     char* tok = NULL;
 
-    if(argc < 3 || argc > 4)
-        printf("usage: %s <string> <to replace> <with what>",argv[0]);
+    if(argc < 3 || argc > 5)
+        printf("usage: %s [-q] <string> <to replace> [<with what>]",argv[0]);
 
-    if(argc == 4) with_what = argv[3];
+    //use -q to quote output
+    if(strcmp(argv[1],"-q") == 0) q = 1;
 
-    tok = strtok(argv[1],argv[2]);
+    if(argc == 4+q) with_what = argv[3+q];
+
+    tok = strtok(argv[1+q],argv[2+q]);
     while(tok)
     {
-        printf("%s",tok);
-        tok = strtok(NULL,argv[2]);
+        if(q) printf("\"%s\"",tok);
+        else printf("%s",tok);
+
+        tok = strtok(NULL,argv[2+q]);
         if(tok) printf("%s",with_what);
     }
     printf("\n");
